import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'

const getFlex = ({ flex, flexAuto, flexNone }) => {
  if ((typeof flex === 'boolean' && flex)
   || flexAuto) return `flex: auto;`
  if (flexNone) return `flex: none;`
  if (flex) return `flex: ${flex};`
  return ''
}

const getFlexDirection = ({ flexColumn, flexDirection }) => {
  if (flexColumn) return `flex-direction: column;`
  if (flexDirection) return `flex-direction: ${flexDirection};`
  return ''
}

const getFlexWrap = ({ flexWrap }) => {
  if (flexWrap) return `flex-wrap: wrap;`
  return ''
}

const styles = ({
  flex,
  flexAuto,
  flexNone,
  flexColumn,
  flexDirection,
  flexWrap,
  alignItems,
  justifyContent
}) => css`
  ${getFlex({ flex, flexAuto, flexNone })}
  ${getFlexDirection({ flexColumn, flexDirection })}
  ${getFlexWrap({ flexWrap })}
  ${alignItems ? `align-items: ${alignItems};` : ''}
  ${justifyContent ? `justify-content: ${justifyContent};` : ''}
`

const withFlex = (Comp) => {
  const FlexComp = styled(({
    flex,
    flexAuto,
    flexNone,
    flexColumn,
    flexDirection,
    flexWrap,
    alignItems,
    justifyContent,
    ...props
  }) => React.createElement(Comp, props))`${styles}`

  FlexComp.propTypes = {
    ...Comp.propTypes,
    flex: PropTypes.bool,
    flexAuto: PropTypes.bool,
    flexNone: PropTypes.bool,
    flexColumn: PropTypes.bool,
    flexWrap: PropTypes.bool,
    alignItems: PropTypes.oneOf([
      'stretch',
      'center',
      'baseline',
      'flex-start',
      'flex-end'
    ]),
    justifyContent: PropTypes.oneOf([
      'center',
      'space-around',
      'space-between',
      'flex-start',
      'flex-end'
    ]),
    flexDirection: PropTypes.oneOf([
      'row',
      'row-reverse',
      'column',
      'column-reverse'
    ])
  }

  FlexComp.displayName = Comp.displayName

  return FlexComp
}

export {
  withFlex
}
