import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  BottomSheet,
  Pane,
  Button,
  Content
} from '../components'

class BottomSheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open BottomSheet</Button>
        <BottomSheet side={this.props.side} isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </BottomSheet>
      </Pane>
    )
  }
}

export default function BottomSheetStory (module) {
  storiesOf('Bottom Sheet', module)
    .add('usage', () => (
      <App white>
        <Pane padding={10}>
          <Content markdown>
{`
# BottomSheet

The BottomSheet component. Implement the \`<Pane />\` component.\

* Don't put spacing on the BottomSheet itself, the close button will me misaligned

\`\`\`
class BottomSheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open BottomSheet</Button>
        <BottomSheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </BottomSheet>
      </Pane>
    )
  }
}

<BottomSheetTrigger />
\`\`\`

`}
          </Content>
          <BottomSheetTrigger />
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`isOpen\` | boolean | undefined | is the BottomSheet open
\`onClose\` | function | undefined | onClose handler to manage state
`}
          </Content>
        </Pane>
      </App>
    )).add('plain', () => (
      <App padding>
        <BottomSheetTrigger />
      </App>
    ))
}
